@@ -807,7 +807,7 @@ class pulsar_dummy_transport(base_dummy_transport):
     """
 
     #--------------------------------------------------------------------------
-    def __init__(self, acq_scope_cfg_format: str, sequencer_cfg_format: str) -> None:
+    def __init__(self, acq_scope_cfg_format: str, sequencer_cfg_format: str, is_rf_type: bool = False) -> None:
         """
         Create Pulsar dummy transport class.
 
@@ -819,6 +819,8 @@ class pulsar_dummy_transport(base_dummy_transport):
         sequencer_cfg_format : str
             Configuration format based on `struct.pack <https://docs.python.org/3/library/struct.html>`_ format
             used to calculate sequencer configuration transaction size.
+        is_rf_type : bool
+            Dummy module type (False = RF, True = baseband)
 
         Returns
         ----------
@@ -829,6 +831,7 @@ class pulsar_dummy_transport(base_dummy_transport):
 
         super(pulsar_dummy_transport, self).__init__()
 
+        self._lo_hw_present          = is_rf_type
         self._asm_status             = False
         self._asm_log                = ''
         self._acq_scope_cfg          = {}
@@ -840,6 +843,7 @@ class pulsar_dummy_transport(base_dummy_transport):
         self._acq_acquisitions       = {}
         self._channelmap             = {}
 
+        self._cmds["LO:PRESent?"]                                = self._get_lo_hw_present
         self._cmds["STATus:ASSEMbler:SUCCess?"]                  = self._get_assembler_status
         self._cmds["STATus:ASSEMbler:LOG?"]                      = self._get_assembler_log
         self._cmds["ACQ:SCOpe:CONFiguration"]                    = self._set_acq_scope_config
@@ -879,6 +883,28 @@ class pulsar_dummy_transport(base_dummy_transport):
         self._cmds["SEQuencer#:CHANnelmap"]                      = self._set_channelmap
         self._cmds["SEQuencer#:CHANnelmap?"]                     = self._get_channelmap
 
+    #--------------------------------------------------------------------------
+    def _get_lo_hw_present(self, cmd_params: list, cmd_args: list, bin_in: bytes) -> None:
+        """
+        Get assembler status. Refer to the assembler log to get more information regarding the assembler result.
+
+        Parameters
+        ----------
+        cmd_params : list
+            Command parameters indicated by '#' in the command.
+        cmd_args : list
+            Command arguments.
+        bin_in : bytes
+            Binary input data.
+
+        Returns
+        ----------
+
+        Raises
+        ----------
+        """
+
+        self._data_out = str(int(self._lo_hw_present))
 
     #--------------------------------------------------------------------------
     def _get_assembler_status(self, cmd_params: list, cmd_args: list, bin_in: bytes) -> None:
@@ -1114,7 +1140,7 @@ class pulsar_dummy_transport(base_dummy_transport):
         else:
             self._awg_waveforms[cmd_params[0]] = {}
             index = 0
-        self._awg_waveforms[cmd_params[0]][cmd_args[0]] = {"wave": [], "index": index}
+        self._awg_waveforms[cmd_params[0]][cmd_args[0]] = {"wave": bytearray([]), "index": index}
 
     #--------------------------------------------------------------------------
     def _del_awg_waveform(self, cmd_params: list, cmd_args: list, bin_in: bytes) -> None:
@@ -1426,7 +1452,7 @@ class pulsar_dummy_transport(base_dummy_transport):
         else:
             self._acq_weights[cmd_params[0]] = {}
             index = 0
-        self._acq_weights[cmd_params[0]][cmd_args[0]] = {"wave": [], "index": index}
+        self._acq_weights[cmd_params[0]][cmd_args[0]] = {"wave": bytearray([]), "index": index}
 
     #--------------------------------------------------------------------------
     def _del_acq_weight(self, cmd_params: list, cmd_args: list, bin_in: bytes) -> None:
@@ -1739,7 +1765,7 @@ class pulsar_dummy_transport(base_dummy_transport):
         else:
             self._acq_acquisitions[cmd_params[0]] = {}
             index = 0
-        self._acq_acquisitions[cmd_params[0]][cmd_args[0]] = {"acq": {"scope": {"data": [[],[]], "or": [False, False], "avg_cnt": [0, 0]}, "bins": [{"valid": False, "int": [0, 0], "thres": 0, "avg_cnt": 0} for _ in range(0, int(cmd_args[1]))]}, "index": index}
+        self._acq_acquisitions[cmd_params[0]][cmd_args[0]] = {"acq": {"scope": {"data": [bytearray([]),bytearray([])], "or": [False, False], "avg_cnt": [0, 0]}, "bins": [{"valid": False, "int": [0, 0], "thres": 0, "avg_cnt": 0} for _ in range(0, int(cmd_args[1]))]}, "index": index}
 
     #--------------------------------------------------------------------------
     def _del_acq_acquisition(self, cmd_params: list, cmd_args: list, bin_in: bytes) -> None:
