@@ -228,8 +228,8 @@ class pulsar_qcm_ifc(pulsar_qcm_scpi_ifc):
         """
 
         seq_proc_cfg_format  = '?I'
-        awg_cfg_format       = '??IIIIIIIIIII?III??I'
-        awg_float_cfg_format = 'fdffff'
+        awg_cfg_format       = '??IIIIIIIIIII?IIIIIII??I'
+        awg_float_cfg_format = 'fdffffff'
 
         return seq_proc_cfg_format + awg_cfg_format + awg_float_cfg_format
 
@@ -264,38 +264,44 @@ class pulsar_qcm_ifc(pulsar_qcm_scpi_ifc):
 
             #Set new configuration
             cfg = [#Sequence processor
-                   cfg_dict["sync_en"],                           #Sequence processor synchronization enable
-                   0,                                             #Sequence processor program counter start (unused)
+                   cfg_dict["sync_en"],                                 #Sequence processor synchronization enable
+                   0,                                                   #Sequence processor program counter start (unused)
 
                    #AWG
-                   cfg_dict["cont_mode_en_awg_path_0"],           #Continuous mode enable for AWG path 0
-                   cfg_dict["cont_mode_en_awg_path_1"],           #Continuous mode enable for AWG path 1
-                   cfg_dict["cont_mode_waveform_idx_awg_path_0"], #continuous mode waveform index for AWG path 0
-                   cfg_dict["cont_mode_waveform_idx_awg_path_1"], #Continuous mode waveform index for AWG path 1
-                   cfg_dict["upsample_rate_awg_path_0"],          #Upsample rate for AWG path 0
-                   cfg_dict["upsample_rate_awg_path_1"],          #Upsample rate for AWG path 1
-                   0,                                             #Gain for AWG path 0         (unused)
-                   0,                                             #Gain for AWG path 1         (unused)
-                   0,                                             #Offset for AWG path 0       (unused)
-                   0,                                             #Offset for AWG path 1       (unused)
-                   0,                                             #Phase increment; ultra-fine (unused)
-                   0,                                             #Phase increment; fine       (unused)
-                   0,                                             #Phase increment; coarse     (unused)
-                   0,                                             #Phase increment; sign       (unused)
-                   0,                                             #Phase; ultra-fine           (unused)
-                   0,                                             #Phase; fine                 (unused)
-                   0,                                             #Phase; coarse               (unused)
-                   cfg_dict["mod_en_awg"],                        #Modulation enable for AWG paths 0 and 1
-                   cfg_dict["mrk_ovr_en"],                        #Marker override enable
-                   cfg_dict["mrk_ovr_val"],                       #Marker override value
+                   cfg_dict["cont_mode_en_awg_path_0"],                 #Continuous mode enable for AWG path 0
+                   cfg_dict["cont_mode_en_awg_path_1"],                 #Continuous mode enable for AWG path 1
+                   cfg_dict["cont_mode_waveform_idx_awg_path_0"],       #continuous mode waveform index for AWG path 0
+                   cfg_dict["cont_mode_waveform_idx_awg_path_1"],       #Continuous mode waveform index for AWG path 1
+                   cfg_dict["upsample_rate_awg_path_0"],                #Upsample rate for AWG path 0
+                   cfg_dict["upsample_rate_awg_path_1"],                #Upsample rate for AWG path 1
+                   0,                                                   #Gain for AWG path 0         (unused)
+                   0,                                                   #Gain for AWG path 1         (unused)
+                   0,                                                   #Offset for AWG path 0       (unused)
+                   0,                                                   #Offset for AWG path 1       (unused)
+                   0,                                                   #Phase increment; ultra-fine (unused)
+                   0,                                                   #Phase increment; fine       (unused)
+                   0,                                                   #Phase increment; coarse     (unused)
+                   0,                                                   #Phase increment; sign       (unused)
+                   0,                                                   #Phase; ultra-fine           (unused)
+                   0,                                                   #Phase; fine                 (unused)
+                   0,                                                   #Phase; coarse               (unused)
+                   0,                                                   #Mixer correction matrix a11 (unsued)
+                   0,                                                   #Mixer correction matrix a12 (unsued)
+                   0,                                                   #Mixer correction matrix a21 (unsued)
+                   0,                                                   #Mixer correction matrix a22 (unsued)
+                   cfg_dict["mod_en_awg"],                              #Modulation enable for AWG paths 0 and 1
+                   cfg_dict["mrk_ovr_en"],                              #Marker override enable
+                   cfg_dict["mrk_ovr_val"],                             #Marker override value
 
                    #AWG floating point values to be converted
-                   cfg_dict["phase_offs_degree"],                 #Phase offset in degrees
-                   cfg_dict["freq_hz"],                           #Frequency in Hz
-                   cfg_dict["gain_awg_path_0_float"],             #Gain for AWG path 0 as float
-                   cfg_dict["gain_awg_path_1_float"],             #Gain for AWG path 1 as float
-                   cfg_dict["offset_awg_path_0_float"],           #Offset for AWG path 0 as float
-                   cfg_dict["offset_awg_path_1_float"]]           #Offset for AWG path 1 as float
+                   cfg_dict["phase_offs_degree"],                       #Phase offset in degrees
+                   cfg_dict["freq_hz"],                                 #Frequency in Hz
+                   cfg_dict["gain_awg_path_0_float"],                   #Gain for AWG path 0 as float
+                   cfg_dict["gain_awg_path_1_float"],                   #Gain for AWG path 1 as float
+                   cfg_dict["offset_awg_path_0_float"],                 #Offset for AWG path 0 as float
+                   cfg_dict["offset_awg_path_1_float"],                 #Offset for AWG path 1 as float
+                   cfg_dict["mixer_corr_phase_offset_degree_float"],    #NCO compensation for mixer: phase offset
+                   cfg_dict["mixer_corr_gain_ratio_float"]]             #NCO compensation for mixer: gain imbalance
 
             super()._set_sequencer_config(sequencer, struct.pack(pulsar_qcm_ifc._get_sequencer_cfg_format(), *cfg))
         except:
@@ -329,30 +335,106 @@ class pulsar_qcm_ifc(pulsar_qcm_scpi_ifc):
         try:
             cfg      = struct.unpack(pulsar_qcm_ifc._get_sequencer_cfg_format(), super()._get_sequencer_config(sequencer))
             cfg_dict = {#Sequence processor
-                        "sync_en":                           cfg[0],
+                        "sync_en":                              cfg[0],
 
                         #AWG
-                        "cont_mode_en_awg_path_0":           cfg[2],
-                        "cont_mode_en_awg_path_1":           cfg[3],
-                        "cont_mode_waveform_idx_awg_path_0": cfg[4],
-                        "cont_mode_waveform_idx_awg_path_1": cfg[5],
-                        "upsample_rate_awg_path_0":          cfg[6],
-                        "upsample_rate_awg_path_1":          cfg[7],
-                        "mod_en_awg":                        cfg[19],
-                        "mrk_ovr_en":                        cfg[20],
-                        "mrk_ovr_val":                       cfg[21],
+                        "cont_mode_en_awg_path_0":              cfg[2],
+                        "cont_mode_en_awg_path_1":              cfg[3],
+                        "cont_mode_waveform_idx_awg_path_0":    cfg[4],
+                        "cont_mode_waveform_idx_awg_path_1":    cfg[5],
+                        "upsample_rate_awg_path_0":             cfg[6],
+                        "upsample_rate_awg_path_1":             cfg[7],
+                        "mod_en_awg":                           cfg[23],
+                        "mrk_ovr_en":                           cfg[24],
+                        "mrk_ovr_val":                          cfg[25],
 
                         #AWG floating point values
-                        "phase_offs_degree":                 cfg[22],
-                        "freq_hz":                           cfg[23],
-                        "gain_awg_path_0_float":             cfg[24],
-                        "gain_awg_path_1_float":             cfg[25],
-                        "offset_awg_path_0_float":           cfg[26],
-                        "offset_awg_path_1_float":           cfg[27]}
+                        "phase_offs_degree":                    cfg[26],
+                        "freq_hz":                              cfg[27],
+                        "gain_awg_path_0_float":                cfg[28],
+                        "gain_awg_path_1_float":                cfg[29],
+                        "offset_awg_path_0_float":              cfg[30],
+                        "offset_awg_path_1_float":              cfg[31],
+                        "mixer_corr_phase_offset_degree_float": cfg[32],
+                        "mixer_corr_gain_ratio_float":          cfg[33]}
             return cfg_dict
         except:
             raise
 
+#---------------------------------------------------------------------------
+    def _set_sequencer_channel_map(self, sequencer, output, enable):
+        """
+        Set enable of the indexed sequencer's path to output.
+        If an invalid sequencer index is given or the channel map is not valid, an error is set in
+        system error.
+
+        Parameters
+        ----------
+        sequencer : int
+            Sequencer index.
+        output : int
+            output index.
+        enable : bool
+            Sequencer path to output enable
+
+        Returns
+        ----------
+
+        Raises
+        ----------
+        Exception
+            Invalid input parameter type.
+        Exception
+            An error is reported in system error and debug <= 1.
+            All errors are read from system error and listed in the exception.
+        """
+        try:
+            channel_map_bin = super()._get_sequencer_channel_map(sequencer)
+            channel_map     = list(struct.unpack("I"*int(len(channel_map_bin)/4),channel_map_bin))
+            if not output in channel_map and enable:
+                channel_map.append(output)
+            elif output in channel_map and not enable:
+                channel_map.remove(output)
+            super()._set_sequencer_channel_map(sequencer, struct.pack('I'*len(channel_map),*channel_map))
+        except:
+            raise
+
+    #---------------------------------------------------------------------------
+    def _get_sequencer_channel_map(self, sequencer, output):
+        """
+        Get enable of the indexed sequencer's path to output.
+        If an invalid sequencer index is given or the channel map is not valid, an error is set in
+        system error.
+
+        Parameters
+        ----------
+        sequencer : int
+            Sequencer index.
+        output : int
+            output index.
+
+        Returns
+        ----------
+        bytes
+            channel map list.
+
+        Raises
+        ----------
+        Exception
+            Invalid input parameter type.
+        Exception
+            An error is reported in system error and debug <= 1.
+            All errors are read from system error and listed in the exception.
+        """
+
+        try:
+            channel_map_bin = super()._get_sequencer_channel_map(sequencer)
+            channel_map     = list(struct.unpack("I"*int(len(channel_map_bin)/4),channel_map_bin))
+
+            return output in channel_map
+        except:
+            raise
+
 
 
     #--------------------------------------------------------------------------
