@@ -615,6 +615,35 @@ class pulsar_qrm_qcodes(pulsar_qrm_ifc, Instrument):
                 get_cmd    = partial(self._get_sequencer_config_val, seq_idx, "discr_threshold")
             )
 
+    #--------------------------------------------------------------------------
+    def _invalidate_qcodes_parameter_cache(self):
+        """
+        Marks the cache of all qcodes parameters on this instrument as invalid.
+        """
+        instrument_parameters = self.parameters.values()
+        for parameter in instrument_parameters:
+            parameter.cache.invalidate()
+
+    #--------------------------------------------------------------------------
+    def reset(self):
+        """
+        Resets device, invalidates QCoDeS parameter cache and clears all status and event registers (see `SCPI <https://www.ivifoundation.org/docs/scpi-99.pdf>`_).
+
+        Parameters
+        ----------
+
+        Returns
+        ----------
+
+        Raises
+        ----------
+        Exception
+            An error is reported in system error and debug <= 1.
+            All errors are read from system error and listed in the exception.
+        """
+        self._invalidate_qcodes_parameter_cache()
+        super().reset()
+
     #--------------------------------------------------------------------------
     def _set_acq_scope_config_val(self, param, val):
         """
@@ -784,6 +813,29 @@ class pulsar_qrm_qcodes(pulsar_qrm_ifc, Instrument):
         except:
             raise
 
+    #--------------------------------------------------------------------------
+    def __repr__(self) -> str:
+        """
+        Returns simplified representation of class giving just the class, name and connection.
+
+        Parameters
+        ----------
+
+        Returns
+        ----------
+        str
+            String representation of class.
+
+        Raises
+        ----------
+        """
+
+        loc_str = ""
+        if hasattr(self._transport, '_socket'):
+            address, port = self._transport._socket.getpeername()
+            loc_str = f" at {address}:{port}"
+        return f"<{type(self).__name__}: {self.name}" + loc_str + ">"
+
 #-- class ---------------------------------------------------------------------
 
 class pulsar_qrm(pulsar_qrm_qcodes):
@@ -832,7 +884,7 @@ class pulsar_qrm_dummy(pulsar_qrm_qcodes):
     """
 
     #--------------------------------------------------------------------------
-    def __init__(self, name, debug=1):
+    def __init__(self, name, debug=1, is_rf_type=False):
         """
         Creates Pulsar QRM driver object. The debug level must be set to >= 1.
 
@@ -842,6 +894,8 @@ class pulsar_qrm_dummy(pulsar_qrm_qcodes):
             Instrument name.
         debug : int
             Debug level (0 = normal, 1 = no version check, >1 = no version or error checking).
+        is_rf_type : bool
+            Dummy module type (False = RF, True = baseband)
 
         Returns
         ----------
@@ -851,7 +905,7 @@ class pulsar_qrm_dummy(pulsar_qrm_qcodes):
         """
 
         #Create transport layer (socket interface)
-        transport_inst = pulsar_dummy_transport(pulsar_qrm_ifc._get_acq_scope_config_format(), pulsar_qrm_ifc._get_sequencer_cfg_format())
+        transport_inst = pulsar_dummy_transport(pulsar_qrm_ifc._get_acq_scope_config_format(), pulsar_qrm_ifc._get_sequencer_cfg_format(), is_rf_type)
 
         #Initialize parent classes.
         super(pulsar_qrm_dummy, self).__init__(name, transport_inst, debug)
