@@ -22,9 +22,9 @@ def get_build_info():
     ----------
     """
 
-    return {"version": "0.5.2",
-            "date":    "11/10/2021-15:51:27",
-            "hash":    "0xF668D53D",
+    return {"version": "0.5.3",
+            "date":    "26/11/2021-13:59:16",
+            "hash":    "0x03E382E4",
             "dirty":   False}
 
 
